@@ -6,11 +6,11 @@ import pytest
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_iteration(mode, buffering):
     """Test iterating over lines from a file."""
-    filename = join(dirname(__file__), '..', 'resources', 'multiline_file.txt')
+    filename = join(dirname(__file__), "..", "resources", "multiline_file.txt")
 
     async with aioopen(filename, mode=mode, buffering=buffering) as file:
         # Append mode needs us to seek.
@@ -22,27 +22,27 @@ async def test_simple_iteration(mode, buffering):
             line = await file.readline()
             if not line:
                 break
-            assert line.strip() == b'line ' + str(counter).encode()
+            assert line.strip() == b"line " + str(counter).encode()
             counter += 1
 
         counter = 1
         await file.seek(0)
         # The new iteration pattern:
         async for line in file:
-            assert line.strip() == b'line ' + str(counter).encode()
+            assert line.strip() == b"line " + str(counter).encode()
             counter += 1
 
     assert file.closed
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_readlines(mode, buffering):
     """Test the readlines functionality."""
-    filename = join(dirname(__file__), '..', 'resources', 'multiline_file.txt')
+    filename = join(dirname(__file__), "..", "resources", "multiline_file.txt")
 
-    with open(filename, mode='rb') as f:
+    with open(filename, mode="rb") as f:
         expected = f.readlines()
 
     async with aioopen(str(filename), mode=mode) as file:
@@ -55,48 +55,48 @@ async def test_simple_readlines(mode, buffering):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb+', 'wb', 'ab'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb+", "wb", "ab"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_flush(mode, buffering, tmpdir):
     """Test flushing to a file."""
-    filename = 'file.bin'
+    filename = "file.bin"
 
     full_file = tmpdir.join(filename)
 
-    if 'r' in mode:
+    if "r" in mode:
         full_file.ensure()  # Read modes want it to already exist.
 
     async with aioopen(str(full_file), mode=mode, buffering=buffering) as file:
-        await file.write(b'0')  # Shouldn't flush.
+        await file.write(b"0")  # Shouldn't flush.
 
         if buffering == -1:
-            assert b'' == full_file.read_binary()
+            assert b"" == full_file.read_binary()
         else:
-            assert b'0' == full_file.read_binary()
+            assert b"0" == full_file.read_binary()
 
         await file.flush()
 
-        assert b'0' == full_file.read_binary()
+        assert b"0" == full_file.read_binary()
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb+', 'wb+', 'ab+'])
+@pytest.mark.parametrize("mode", ["rb+", "wb+", "ab+"])
 async def test_simple_peek(mode, tmpdir):
     """Test flushing to a file."""
-    filename = 'file.bin'
+    filename = "file.bin"
 
     full_file = tmpdir.join(filename)
-    full_file.write_binary(b'0123456789')
+    full_file.write_binary(b"0123456789")
 
     async with aioopen(str(full_file), mode=mode) as file:
-        if 'a' in mode:
+        if "a" in mode:
             await file.seek(0)  # Rewind for append modes.
 
         peeked = await file.peek(1)
 
         # Technically it's OK for the peek to return less bytes than requested.
         if peeked:
-            assert peeked.startswith(b'0')
+            assert peeked.startswith(b"0")
 
             read = await file.read(1)
 
@@ -104,26 +104,26 @@ async def test_simple_peek(mode, tmpdir):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_read(mode, buffering):
     """Just read some bytes from a test file."""
-    filename = join(dirname(__file__), '..', 'resources', 'multiline_file.txt')
+    filename = join(dirname(__file__), "..", "resources", "multiline_file.txt")
     async with aioopen(filename, mode=mode, buffering=buffering) as file:
         await file.seek(0)  # Needed for the append mode.
 
         actual = await file.read()
 
-        assert b'' == (await file.read())
-    assert actual == open(filename, mode='rb').read()
+        assert b"" == (await file.read())
+    assert actual == open(filename, mode="rb").read()
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_staggered_read(mode, buffering):
     """Read bytes repeatedly."""
-    filename = join(dirname(__file__), '..', 'resources', 'multiline_file.txt')
+    filename = join(dirname(__file__), "..", "resources", "multiline_file.txt")
     async with aioopen(filename, mode=mode, buffering=buffering) as file:
         await file.seek(0)  # Needed for the append mode.
 
@@ -135,10 +135,10 @@ async def test_staggered_read(mode, buffering):
             else:
                 break
 
-        assert b'' == (await file.read())
+        assert b"" == (await file.read())
 
         expected = []
-        with open(filename, mode='rb') as f:
+        with open(filename, mode="rb") as f:
             while True:
                 byte = f.read(1)
                 if byte:
@@ -150,12 +150,12 @@ async def test_staggered_read(mode, buffering):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_seek(mode, buffering, tmpdir):
     """Test seeking and then reading."""
-    filename = 'bigfile.bin'
-    content = b'0123456789' * 4 * io.DEFAULT_BUFFER_SIZE
+    filename = "bigfile.bin"
+    content = b"0123456789" * 4 * io.DEFAULT_BUFFER_SIZE
 
     full_file = tmpdir.join(filename)
     full_file.write_binary(content)
@@ -163,16 +163,16 @@ async def test_simple_seek(mode, buffering, tmpdir):
     async with aioopen(str(full_file), mode=mode, buffering=buffering) as file:
         await file.seek(4)
 
-        assert b'4' == (await file.read(1))
+        assert b"4" == (await file.read(1))
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['wb', 'rb', 'rb+', 'wb+', 'ab', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
-async def test_simple_close_ctx_mgr(mode, buffering, tmpdir):
+@pytest.mark.parametrize("mode", ["wb", "rb", "rb+", "wb+", "ab", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
+async def test_simple_close_ctx_mgr_iter(mode, buffering, tmpdir):
     """Open a file, read a byte, and close it."""
-    filename = 'bigfile.bin'
-    content = b'0' * 4 * io.DEFAULT_BUFFER_SIZE
+    filename = "bigfile.bin"
+    content = b"0" * 4 * io.DEFAULT_BUFFER_SIZE
 
     full_file = tmpdir.join(filename)
     full_file.write_binary(content)
@@ -186,12 +186,12 @@ async def test_simple_close_ctx_mgr(mode, buffering, tmpdir):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['wb', 'rb', 'rb+', 'wb+', 'ab', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["wb", "rb", "rb+", "wb+", "ab", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_close_ctx_mgr(mode, buffering, tmpdir):
     """Open a file, read a byte, and close it."""
-    filename = 'bigfile.bin'
-    content = b'0' * 4 * io.DEFAULT_BUFFER_SIZE
+    filename = "bigfile.bin"
+    content = b"0" * 4 * io.DEFAULT_BUFFER_SIZE
 
     full_file = tmpdir.join(filename)
     full_file.write_binary(content)
@@ -207,11 +207,11 @@ async def test_simple_close_ctx_mgr(mode, buffering, tmpdir):
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb', 'rb+', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb", "rb+", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_readinto(mode, buffering):
     """Test the readinto functionality."""
-    filename = join(dirname(__file__), '..', 'resources', 'multiline_file.txt')
+    filename = join(dirname(__file__), "..", "resources", "multiline_file.txt")
     async with aioopen(filename, mode=mode, buffering=buffering) as file:
         await file.seek(0)  # Needed for the append mode.
 
@@ -219,16 +219,16 @@ async def test_simple_readinto(mode, buffering):
         bytes_read = await file.readinto(array)
 
         assert bytes_read == 4
-        assert array == open(filename, mode='rb').read(4)
+        assert array == open(filename, mode="rb").read(4)
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['rb+', 'wb', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["rb+", "wb", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_truncate(mode, buffering, tmpdir):
     """Test truncating files."""
-    filename = 'bigfile.bin'
-    content = b'0123456789' * 4 * io.DEFAULT_BUFFER_SIZE
+    filename = "bigfile.bin"
+    content = b"0123456789" * 4 * io.DEFAULT_BUFFER_SIZE
 
     full_file = tmpdir.join(filename)
     full_file.write_binary(content)
@@ -237,7 +237,7 @@ async def test_simple_truncate(mode, buffering, tmpdir):
         # The append modes want us to seek first.
         await file.seek(0)
 
-        if 'w' in mode:
+        if "w" in mode:
             # We've just erased the entire file.
             await file.write(content)
             await file.flush()
@@ -245,20 +245,20 @@ async def test_simple_truncate(mode, buffering, tmpdir):
 
         await file.truncate()
 
-    assert b'' == full_file.read_binary()
+    assert b"" == full_file.read_binary()
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize('mode', ['wb', 'rb+', 'wb+', 'ab', 'ab+'])
-@pytest.mark.parametrize('buffering', [-1, 0])
+@pytest.mark.parametrize("mode", ["wb", "rb+", "wb+", "ab", "ab+"])
+@pytest.mark.parametrize("buffering", [-1, 0])
 async def test_simple_write(mode, buffering, tmpdir):
     """Test writing into a file."""
-    filename = 'bigfile.bin'
-    content = b'0' * 4 * io.DEFAULT_BUFFER_SIZE
+    filename = "bigfile.bin"
+    content = b"0" * 4 * io.DEFAULT_BUFFER_SIZE
 
     full_file = tmpdir.join(filename)
 
-    if 'r' in mode:
+    if "r" in mode:
         full_file.ensure()  # Read modes want it to already exist.
 
     async with aioopen(str(full_file), mode=mode, buffering=buffering) as file:
@@ -271,13 +271,13 @@ async def test_simple_write(mode, buffering, tmpdir):
 @pytest.mark.asyncio
 async def test_simple_detach(tmpdir):
     """Test detaching for buffered streams."""
-    filename = 'file.bin'
+    filename = "file.bin"
 
     full_file = tmpdir.join(filename)
-    full_file.write_binary(b'0123456789')
+    full_file.write_binary(b"0123456789")
 
     with pytest.raises(ValueError):
-        async with aioopen(str(full_file), mode='rb') as file:
+        async with aioopen(str(full_file), mode="rb") as file:
             raw_file = file.detach()
 
             assert raw_file
@@ -285,7 +285,7 @@ async def test_simple_detach(tmpdir):
             with pytest.raises(ValueError):
                 await file.read()
 
-    assert b'0123456789' == raw_file.read(10)
+    assert b"0123456789" == raw_file.read(10)
 
 
 @pytest.mark.asyncio
@@ -294,13 +294,13 @@ async def test_simple_readall(tmpdir):
 
     Only RawIOBase supports readall().
     """
-    filename = 'bigfile.bin'
-    content = b'0' * 4 * io.DEFAULT_BUFFER_SIZE  # Hopefully several reads.
+    filename = "bigfile.bin"
+    content = b"0" * 4 * io.DEFAULT_BUFFER_SIZE  # Hopefully several reads.
 
     sync_file = tmpdir.join(filename)
     sync_file.write_binary(content)
 
-    file = await aioopen(str(sync_file), mode='rb', buffering=0)
+    file = await aioopen(str(sync_file), mode="rb", buffering=0)
 
     actual = await file.readall()
 
@@ -308,5 +308,3 @@ async def test_simple_readall(tmpdir):
 
     await file.close()
     assert file.closed
-
-
